@@ -9,7 +9,7 @@ monitoring state and reporting that data.
 import json
 import os
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
 import requests
 import urllib3
@@ -17,7 +17,7 @@ from requests import Response
 
 from instana.agent.base import BaseAgent
 from instana.collector.host import HostCollector
-from instana.fsm import Discovery, TheMachine
+from instana.fsm import TheMachine
 from instana.log import logger
 from instana.options import StandardOptions
 from instana.util import to_json
@@ -25,6 +25,9 @@ from instana.util.runtime import get_py_source, log_runtime_env_info
 from instana.util.span_utils import get_operation_specifiers
 from instana.version import VERSION
 
+if TYPE_CHECKING:
+    from instana.util.process_discovery import Discovery
+
 
 class AnnounceData(object):
     """The Announce Payload"""
@@ -135,10 +138,15 @@ class HostAgent(BaseAgent):
         @return: None
         """
         self.options.set_from(res_data)
-        self.announce_data = AnnounceData(
-            pid=res_data["pid"],
-            agentUuid=res_data["agentUuid"],
-        )
+
+        # Ensure required keys are present
+        if "pid" in res_data and "agentUuid" in res_data:
+            self.announce_data = AnnounceData(
+                pid=res_data["pid"],
+                agentUuid=res_data["agentUuid"],
+            )
+        else:
+            logger.debug(f"Missing required keys in announce response: {res_data}")
 
     def get_from_structure(self) -> Dict[str, str]:
         """
@@ -176,7 +184,7 @@ class HostAgent(BaseAgent):
 
     def announce(
         self,
-        discovery: Discovery,
+        discovery: "Discovery",
     ) -> Optional[Dict[str, Any]]:
         """
         With the passed in Discovery class, attempt to announce to the host agent.
