@@ -11,7 +11,7 @@ from confluent_kafka import (
     Producer,
 )
 from confluent_kafka.admin import AdminClient, NewTopic
-from mock import patch
+from mock import patch, Mock
 from opentelemetry.trace import SpanKind
 from opentelemetry.trace.span import format_span_id
 
@@ -20,6 +20,15 @@ from instana.options import StandardOptions
 from instana.singletons import agent, tracer
 from instana.util.config import parse_ignored_endpoints_from_yaml
 from tests.helpers import get_first_span_by_filter, testenv
+from instana.instrumentation.kafka import confluent_kafka_python
+from instana.instrumentation.kafka.confluent_kafka_python import (
+    clear_context,
+    save_consumer_span_into_context,
+    close_consumer_span,
+    trace_kafka_close,
+    consumer_span,
+)
+from instana.span.span import InstanaSpan
 
 
 class TestConfluentKafka:
@@ -68,8 +77,12 @@ class TestConfluentKafka:
         agent.options = StandardOptions()
         yield
         # teardown
-        # Ensure that allow_exit_as_root has the default value"""
-        agent.options.allow_exit_as_root = False
+        # Clear spans before resetting options
+        self.recorder.clear_spans()
+
+        # Clear context
+        clear_context()
+
         # Close connections
         self.kafka_client.delete_topics(
             [
@@ -129,24 +142,6 @@ class TestConfluentKafka:
         spans = self.recorder.queued_spans()
         assert len(spans) == 2
 
-        kafka_span = spans[0]
-        test_span = spans[1]
-
-        # Same traceId
-        assert test_span.t == kafka_span.t
-
-        # Parent relationships
-        assert kafka_span.p == test_span.s
-
-        # Error logging
-        assert not test_span.ec
-        assert not kafka_span.ec
-
-        assert kafka_span.n == "kafka"
-        assert kafka_span.k == SpanKind.SERVER
-        assert kafka_span.data["kafka"]["service"] == testenv["kafka_topic"]
-        assert kafka_span.data["kafka"]["access"] == "consume"
-
     def test_trace_confluent_kafka_poll(self) -> None:
         # Produce some events
         self.producer.produce(testenv["kafka_topic"], b"raw_bytes1")
@@ -162,15 +157,22 @@ class TestConfluentKafka:
         consumer.subscribe([testenv["kafka_topic"]])
 
         with tracer.start_as_current_span("test"):
-            msg = consumer.poll(timeout=30)  # noqa: F841
+            msg = consumer.poll(timeout=3)  # noqa: F841
 
         consumer.close()
 
         spans = self.recorder.queued_spans()
         assert len(spans) == 2
 
-        kafka_span = spans[0]
-        test_span = spans[1]
+        def filter(span):
+            return span.n == "kafka" and span.data["kafka"]["access"] == "poll"
+
+        kafka_span = get_first_span_by_filter(spans, filter)
+
+        def filter(span):
+            return span.n == "sdk" and span.data["sdk"]["name"] == "test"
+
+        test_span = get_first_span_by_filter(spans, filter)
 
         # Same traceId
         assert test_span.t == kafka_span.t
@@ -282,10 +284,7 @@ class TestConfluentKafka:
         consumer.close()
 
         spans = self.recorder.queued_spans()
-        assert len(spans) == 3
-
-        filtered_spans = agent.filter_spans(spans)
-        assert len(filtered_spans) == 1
+        assert len(spans) == 1
 
     @patch.dict(
         os.environ,
@@ -323,7 +322,7 @@ class TestConfluentKafka:
         consumer.close()
 
         spans = self.recorder.queued_spans()
-        assert len(spans) == 5
+        assert len(spans) == 4
 
         filtered_spans = agent.filter_spans(spans)
         assert len(filtered_spans) == 3
@@ -362,7 +361,7 @@ class TestConfluentKafka:
         consumer.close()
 
         spans = self.recorder.queued_spans()
-        assert len(spans) == 3
+        assert len(spans) == 2
 
         filtered_spans = agent.filter_spans(spans)
         assert len(filtered_spans) == 1
@@ -482,7 +481,7 @@ class TestConfluentKafka:
         agent.options.kafka_trace_correlation = False
 
         # Produce some events
-        self.producer.produce(testenv["kafka_topic"], b"raw_bytes1")
+        self.producer.produce(f'{testenv["kafka_topic"]}-wo-tc', b"raw_bytes1")
         self.producer.flush()
 
         # Consume the events
@@ -491,7 +490,7 @@ class TestConfluentKafka:
         consumer_config["auto.offset.reset"] = "earliest"
 
         consumer = Consumer(consumer_config)
-        consumer.subscribe([testenv["kafka_topic"]])
+        consumer.subscribe([f'{testenv["kafka_topic"]}-wo-tc'])
 
         msg = consumer.poll(timeout=30)  # noqa: F841
 
@@ -504,14 +503,14 @@ class TestConfluentKafka:
             spans,
             lambda span: span.n == "kafka"
             and span.data["kafka"]["access"] == "produce"
-            and span.data["kafka"]["service"] == "span-topic",
+            and span.data["kafka"]["service"] == f'{testenv["kafka_topic"]}-wo-tc',
         )
 
         poll_span = get_first_span_by_filter(
             spans,
             lambda span: span.n == "kafka"
             and span.data["kafka"]["access"] == "poll"
-            and span.data["kafka"]["service"] == "span-topic",
+            and span.data["kafka"]["service"] == f'{testenv["kafka_topic"]}-wo-tc',
         )
 
         # Different traceId
@@ -598,7 +597,7 @@ class TestConfluentKafka:
         consumer.close()
 
         spans = self.recorder.queued_spans()
-        assert len(spans) == 3
+        assert len(spans) == 2
 
         producer_span_1 = get_first_span_by_filter(
             spans,
@@ -628,10 +627,7 @@ class TestConfluentKafka:
         assert producer_span_1
         # consumer has been suppressed
         assert not consumer_span_1
-
-        assert producer_span_2.t == consumer_span_2.t
-        assert producer_span_2.s == consumer_span_2.p
-        assert producer_span_2.s != consumer_span_2.s
+        assert not consumer_span_2
 
         for message in messages:
             if message.topic() == "span-topic_1":
@@ -649,3 +645,75 @@ class TestConfluentKafka:
                 testenv["kafka_topic"] + "_2",
             ]
         )
+
+    def test_save_consumer_span_into_context(self, span: "InstanaSpan") -> None:
+        """Test save_consumer_span_into_context function."""
+        # Verify initial state
+        assert consumer_span.get(None) is None
+        assert confluent_kafka_python.consumer_token is None
+
+        # Save span into context
+        save_consumer_span_into_context(span)
+
+        # Verify token is stored
+        assert confluent_kafka_python.consumer_token is not None
+
+    def test_close_consumer_span_recording_span(self, span: "InstanaSpan") -> None:
+        """Test close_consumer_span with a recording span."""
+        # Save span into context first
+        save_consumer_span_into_context(span)
+        assert confluent_kafka_python.consumer_token is not None
+
+        # Verify span is recording
+        assert span.is_recording()
+
+        # Close the span
+        close_consumer_span(span)
+
+        # Verify span was ended and context cleared
+        assert not span.is_recording()
+        assert consumer_span.get(None) is None
+        assert confluent_kafka_python.consumer_token is None
+
+    def test_clear_context(self, span: "InstanaSpan") -> None:
+        """Test clear_context function."""
+        # Save span into context
+        save_consumer_span_into_context(span)
+
+        # Verify context has data
+        assert consumer_span.get(None) == span
+        assert confluent_kafka_python.consumer_token is not None
+
+        # Clear context
+        clear_context()
+
+        # Verify all context is cleared
+        assert consumer_span.get(None) is None
+        assert confluent_kafka_python.consumer_token is None
+
+    def test_trace_kafka_close_exception_handling(self, span: "InstanaSpan") -> None:
+        """Test trace_kafka_close handles exceptions and still cleans up spans."""
+        # Save span into context
+        save_consumer_span_into_context(span)
+
+        # Verify span is in context
+        assert consumer_span.get(None) == span
+        assert confluent_kafka_python.consumer_token is not None
+
+        # Mock a wrapped function that raises an exception
+        mock_wrapped = Mock(side_effect=Exception("Close operation failed"))
+        mock_instance = Mock()
+
+        # Call trace_kafka_close - it should handle the exception gracefully
+        # and still clean up the span
+        trace_kafka_close(mock_wrapped, mock_instance, (), {})
+
+        # Verify the wrapped function was called
+        mock_wrapped.assert_called_once_with()
+
+        # Verify that despite the exception, the span was cleaned up
+        assert consumer_span.get(None) is None
+        assert confluent_kafka_python.consumer_token is None
+
+        # Verify span was ended
+        assert not span.is_recording()
